@@ -17,18 +17,13 @@
 #ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
 /**
  * @file globus_ftp_client.c
- *
- * $RCSfile: globus_ftp_client.c,v $
- * $Revision: 1.20 $
- * $Date: 2011/05/19 04:03:42 $
+ * @brief GridFTP Client
  */
-#endif
+#endif /* GLOBUS_DONT_DOCUMENT_INTERNAL */
 
 #include "globus_i_ftp_client.h"
 #include "version.h"
 
-#ifndef GLOBUS_DONT_DOCUMENT_INTERNAL
-
 static int globus_l_ftp_client_activate(void);
 static int globus_l_ftp_client_deactivate(void);
 
@@ -863,7 +858,3 @@ globus_i_ftp_client_count_digits(globus_off_t num)
     return digits;
 }
 /* globus_i_ftp_client_count_digits() */
-
-
-#endif /* GLOBUS_DONT_DOCUMENT_INTERNAL */
-
